@@ -7,7 +7,6 @@ from typing import Any, Dict, List, Tuple
 from ctlml_commons.entity.candle import Candle
 from ctlml_commons.entity.lot import Lot
 from ctlml_commons.entity.news import News
-from ctlml_commons.util.date_utils import timeoffset_as_str
 
 
 class Focus(metaclass=ABCMeta):
@@ -51,19 +50,3 @@ class Focus(metaclass=ABCMeta):
         Returns:
             if lot should be sold and a reason
         """
-
-    @classmethod
-    def _get_periods(cls, a_time, periods: int) -> List[str]:
-        period_names = []
-
-        mins = 0
-        for i in range(periods):
-            period_names.append(timeoffset_as_str(mins * 60, a_time))
-            mins += 1
-
-        period_names.reverse()
-        return period_names[:-1]
-
-    @classmethod
-    def _all_exists(cls, periods: List[str], candle_data: Dict[str, Candle]) -> bool:
-        return set(periods).issubset(candle_data.keys())
