@@ -24,7 +24,7 @@ class Lot:
     b_id: Optional[UUID] = None  # Brokerage external id
 
     def serialize(self) -> Dict[str, Any]:
-        data: Dict[str, Any] = self.__dict__
+        data: Dict[str, Any] = deepcopy(self.__dict__)
 
         for field in ["id", "b_id"]:
             data[field] = str(data[field])
