@@ -1,6 +1,6 @@
 from typing import Any, Dict
 
-from ctlml_commons.entity.focus import Focus, PercentageFocus, PriceFocus
+from ctlml_commons.entity.focus import Focus, PercentageFocus, PriceFocus, PriceUpBuyPercentageSellFocus
 
 
 def str_to_focus(data: Dict[str, Any]) -> Focus:
@@ -11,6 +11,8 @@ def str_to_focus(data: Dict[str, Any]) -> Focus:
             return PriceFocus.deserialize(data)
         elif focus_type == "PercentageFocus":
             return PercentageFocus.deserialize(data)
+        elif focus_type == "PriceUpBuyPercentageSellFocus":
+            return PriceUpBuyPercentageSellFocus.deserialize(data)
     except Exception as e:
         raise e
 
